<TWB_NOSPLIT>#!/bin/sh
# *******************************************************************************
#  Licensed Materials - Property of IBM
#  (c) Copyright IBM Corporation 2012. All Rights Reserved.
#
#  Note to U.S. Government Users Restricted Rights:
#  Use, duplication or disclosure restricted by GSA ADP Schedule
#  Contract with IBM Corp.
#  *******************************************************************************
# NLS_MESSAGEFORMAT_NONE
# NLS_ENCODING=UTF-8


# #############################################################
# #
# # dm_upgrade.sh スクリプト・パラメーターとそのデフォルト値に
# # 対応する環境変数の定義
# #
# #===========================================================
# #
# # このファイルは、dm_upgrade.sh スクリプト実行の開始時に
# # 読み取られます。定義済みのデフォルト値がある
# # 有効なパラメーターごとに 1 つの環境変数を設定します。
# #
# # ユーザーは、デフォルト値を変更して dm_upgrade.sh スクリプト
# # を独自の値で起動することもできます。そうすれば、コマンド・ライン
# # でパラメーターとそれに対応する値を手動で入力する必要
# # はありません。
# #
# # 警告:
# # すべてのアプリケーションにすべての変数を設定する必要は
# # ありません。  値を変更する前に、各コメントを注意深く
# # お読みください。
# #
# #############################################################

# パラメーター: -oldApplicationHome
# 使用法: -oldApplicationHome <dir path>
# 説明:
# 	古いインストール済み環境でのアプリケーション・ホーム・ディレクトリーの絶対パス。
# デフォルト:
# 	<none>
# 制約:
#  - これは必須パラメーターです
#  - <dir path> は 'server/conf'で終了する既存のディレクトリーでなければなりません
#    例: /opt/ibm/JazzInstallDir/server/conf
#
<TWBCTX>OLD_APPLICATION_HOME</TWBCTX>=

# パラメーター: -applicationContextRoot
# 使用法: -applicationContextRoot <root>
# 説明:
# 	アプリケーション・コンテキスト・ルート。
# デフォルト:
# 	dm
# 制約:
#  - <root> は有効な単一のディレクトリー名 (前にスラッシュがないもの) でなければなりません。
#
<TWBCTX>APPLICATION_CONTEXT_ROOT</TWBCTX>=dm

# パラメーター: -oldApplicationVersion
# 使用法: -oldApplicationVersion <version>
# 説明:
# 	アップグレードされている DM バージョンです。 これは、デフォルトで、古い
# アプリケーションに対して repotools -version を実行することで判別されます。
# デフォルト:
# 	<none>
# 制約:
#  - 完全なバージョン・ストリングでなければなりません
#    例: 4.0
#
<TWBCTX>OLD_APPLICATION_VERSION</TWBCTX>=

# パラメーター: -newApplicationHome
# 使用法: -newApplicationHome <dir path>
# 説明:
# 	新規インストールでのアプリケーション・ホーム・ディレクトリーのパス。
# デフォルト:
# 	<currentDir>/conf
# 制約:
#  - これは必須パラメーターです
#  - <dir path> は 'server/conf'で終了する既存のディレクトリーでなければなりません
#    例: /opt/ibm/JazzInstallDir/server/conf
#
<TWBCTX>NEW_APPLICATION_HOME</TWBCTX>="$START_DIR/conf"

# パラメーター: -updateAppServerFiles
# 使用法: -updateAppServerFiles <yes | no>
# 説明:
#   デフォルトのアプリケーション・サーバー (WebSphere Liberty) 構成ファイルを更新するかどうか。
# デフォルト:
#   yes
# 制約:
#  - 有効値は「yes」および「no」のみです。
#
<TWBCTX>UPDATE_APPSERVER_FILES</TWBCTX>=はい

# パラメーター: -updateTomcatFiles
# 使用法: -updateTomcatFiles <yes | no>
# 説明:
#   tomcat 構成ファイルを更新するかどうか。
# デフォルト:
#   no
# 制約:
#  - 有効値は「yes」および「no」のみです。
#
<TWBCTX>UPDATE_TOMCAT_FILES</TWBCTX>=いいえ

# パラメーター: -oldApplicationTomcatHome
# 使用法: -oldApplicationTomcatHome <dir path>
# 説明:
# 	古いインストール済み環境での Tomcat ルート・ディレクトリーの絶対パス。
# デフォルト:
# 	<none>
# 制約:
#  - 既存のディレクトリーでなければなりません
#
<TWBCTX>OLD_APP_TOMCAT_HOME</TWBCTX>=

# パラメーター: -newApplicationTomcatHome
# 使用法: -newApplicationTomcatHome <dir path>
# 説明:
# 	新規インストールでのアプリケーション Tomcat ルート・ディレクトリーのパス。
# デフォルト:
# 	<none>
#
<TWBCTX>NEW_APP_TOMCAT_HOME</TWBCTX>=

# パラメーター: -newJTSHome
# 使用法: -newJTSHome <dir path>
# 説明:
# 	新規インストール済み環境で使用される JTS の JTS サーバー構成ディレクトリーへのパス。
# デフォルト:
# 	新規アプリケーション・ホーム・ディレクトリー
# 制約:
#  - <dir path> は 'server/conf'で終了する既存のディレクトリーでなければなりません
#
<TWBCTX>NEW_JTS_HOME</TWBCTX>=

# パラメーター: -jtsContextRoot
# 使用法: -jtsContextRoot <root>
# 説明:
# 	JTS サーバーのコンテキスト・ルート。
# デフォルト:
# 	jts
# 制約:
#  -  <root> は有効な単一のディレクトリー名 (前にスラッシュがないもの) でなければなりません。
#
<TWBCTX>JTS_CONTEXT_ROOT</TWBCTX>=jts

# パラメーター: -noPrompt
# 使用法: -noPrompt
# 説明:
# 	表を作成または変更する前にプロンプトを出さない。
# デフォルト:
# 	<none>
# 制約:
#  - 有効値は空または「noPrompt」のみです。
#
# NO_PROMPT=noPrompt
<TWBCTX>NO_PROMPT</TWBCTX>=

# パラメーター: -noVerify
# 使用法: -noVerify
# 説明:
# 	teamserver.properties ファイルの検査を実行しない。
# デフォルト:
# 	<none>
# 制約:
#  - 有効値は空または「noVerify」のみです。
#
# NO_VERIFY=noVerify
<TWBCTX>NO_VERIFY</TWBCTX>=

# パラメーター: -overwrite
# 使用法: -overwrite
# 説明:
# 	既存のファイルを上書きするかどうか。
# デフォルト:
# 	no
# 制約:
#  - 有効値は空または「overwrite=yes」のみです。
#
# OVERWRITE=overwrite=yes
<TWBCTX>OVERWRITE</TWBCTX>=

# パラメーター: -noStepPrompt
# 使用法: -noStepPrompt
# 説明:
# 	ステップを実行する前にプロンプトを出さない。
# デフォルト:
# 	false
# 制約:
#  - 有効値は「true」または「false」のみです。
#
# NO_STEP_PROMPT=true
<TWBCTX>NO_STEP_PROMPT</TWBCTX>=false
